@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: CloudServices.py 1197 2021-08-16 06:40:19Z Casey $
+# $Id: CloudServices.py 1208 2021-08-22 04:58:20Z Casey $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $
-# $Date: 2021-08-16 14:40:19 +0800 (Mon, 16 Aug 2021) $
-# $Revision: 1197 $
+# $Date: 2021-08-22 12:58:20 +0800 (Sun, 22 Aug 2021) $
+# $Revision: 1208 $
 
 import json
 import socket
@@ -49,7 +49,7 @@ class BaseServices(object):
     
     name = "Base"
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomain=None):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None):
         return {
             
         }
@@ -59,7 +59,7 @@ class CloudflareService(BaseServices):
 
     name = "Cloudflare DNS"
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomain=None):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None):
         # cf
         cf = Cloudflare(CLOUDFLARE_EMAIL, CLOUDFLARE_API_KEY)
         subdomain = tldextract.extract(domain).subdomain
@@ -85,10 +85,8 @@ class CloudflareService(BaseServices):
 
         domains = []
         domains.append(domain)
-        if aliasDomain:
-            # aliasDomain 可能會有多個，且用逗號區隔
-            aliasDomain = aliasDomain.split(",")
-            for alias in aliasDomain:
+        if aliasDomainList:
+            for alias in aliasDomainList:
                 domains.append(alias)
         
         # check dns 
@@ -380,7 +378,7 @@ class HealthchecksService(BaseServices):
         return hchkAPIKey, integrations
         
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomain=None):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None):
         # connect 
         browser = self.loginHealthchecks()
        
@@ -474,7 +472,7 @@ class SentryService(BaseServices):
         browser["email"] = managerEmail
         browser.submit_selected()
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomain=None):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None):
         # connect 
         browser = self.loginSentry()
         
